"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const zhin_1 = require("zhin");
const web_wechat_1 = require("web-wechat");
const utils_1 = require("./utils");
(0, zhin_1.defineMetadata)({ name: 'Web Wechat adapter' });
const wechatAdapter = (0, zhin_1.registerAdapter)('web-wechat');
class WechatClient extends zhin_1.Adapter.BaseBot {
    constructor(config) {
        super(wechatAdapter, config.unique_id, new web_wechat_1.Client(config));
    }
    async handleSendMessage(channel, message, source) {
        const [target_type, ...other] = channel.split(':');
        const target_id = other.join(':');
        const msg = (0, utils_1.formatSendable)(message);
        switch (target_type) {
            case 'group':
                return (await this.sendGroupMsg(target_id, msg));
            case 'private':
                return (await this.sendPrivateMsg(target_id, msg));
            default:
                throw new Error(`wechat适配器暂不支持发送${target_type}类型的消息`);
        }
    }
}
const startBots = (configs) => {
    for (const config of configs) {
        const bot = new WechatClient(config);
        bot.on('message', messageHandler.bind(global, bot));
        bot.start().then(() => {
            wechatAdapter.emit('bot-ready', bot);
        });
        wechatAdapter.bots.push(bot);
    }
};
const messageHandler = (bot, event) => {
    const message = zhin_1.Message.from(wechatAdapter, bot, {
        channel: `${event.message_type}:${event instanceof web_wechat_1.PrivateMessageEvent ? event.user_id : event.group_id}`,
        message_id: event.message_id,
        raw_message: (0, utils_1.sendableToString)(event.message).trim(),
        message_type: event.message_type,
        sender: {
            ...event.sender,
            permissions: [],
        },
    });
    wechatAdapter.app.emit('message', message);
};
const stopBots = () => {
    for (const bot of wechatAdapter.bots) {
        bot.stop();
    }
};
wechatAdapter.on('start', startBots);
wechatAdapter.on('stop', stopBots);
